.. _templatetags:

Template Tags
=============

.. module:: stories.relations.templatetags.story_relation_tags

.. autoclass:: RelatedNode
   :members:
   :undoc-members:

.. autofunction:: do_get_related_content

.. autofunction:: do_get_related_content_type

.. autofunction:: do_get_relation_type


.. module:: stories.templatetags.quickedit

.. autofunction:: results

.. autofunction:: qe_result_list
